gssettingsuis/Gs/GSFramework/src/GSParentContainer.cpp
branchRCL_3
changeset 13 23553eb4e470
parent 8 f62c3a3d66b8
child 20 9941bcf99348
--- a/gssettingsuis/Gs/GSFramework/src/GSParentContainer.cpp	Fri Mar 12 15:43:47 2010 +0200
+++ b/gssettingsuis/Gs/GSFramework/src/GSParentContainer.cpp	Mon Mar 15 12:41:46 2010 +0200
@@ -834,42 +834,40 @@
     }
 
 // -----------------------------------------------------------------------------
-// CGSParentContainer::GetPositionL()
+// CGSParentContainer::StoreListBoxPositionL
 //
 //Get the exact position of listbox.
 // -----------------------------------------------------------------------------
 //
-void CGSParentContainer::GetPositionL(RArray<TInt>& aPosition)
+void CGSParentContainer::StoreListBoxPositionL( CGSParentPlugin::TListBoxPosition& aPosition )
 	{
-	aPosition.AppendL(iListBox->CurrentItemIndex());
-	aPosition.AppendL(iListBox->View()->ItemOffsetInPixels());
-	aPosition.AppendL(iListBox->View()->TopItemIndex());
-	return;
+    aPosition.iCurrentItemIndex = iListBox->CurrentItemIndex();
+    aPosition.iItemOffsetInPixels = iListBox->View()->ItemOffsetInPixels();
+    aPosition.iTopItemIndex = iListBox->View()->TopItemIndex();
 	}
 
 // -----------------------------------------------------------------------------
-// CGSParentContainer::GetPositionL()
+// CGSParentContainer::RestoreListBoxPositionL
 //
 //Get the exact position of listbox.
 // -----------------------------------------------------------------------------
 //
-void CGSParentContainer::SetPosition(const RArray<TInt>& aPosition, TBool aChangeMode)
+void CGSParentContainer::RestoreListBoxPositionL( const CGSParentPlugin::TListBoxPosition& aPosition, TBool aScreenModeChanged )
 	{
-    if ( aPosition.operator[](0) >= 0 )
+    if ( aPosition.iCurrentItemIndex >= 0 )
         {
-        iListBox->SetCurrentItemIndex( aPosition.operator[](0) );
+        iListBox->SetCurrentItemIndex( aPosition.iCurrentItemIndex );
         }
     
-    //iListBox->View()->SetItemOffsetInPixels( aPosition.operator[](1) );
-    if (aChangeMode)
+    if ( aScreenModeChanged )
         {
-        iListBox->View()->VerticalMoveToItemL( aPosition.operator[](0),
+        iListBox->View()->VerticalMoveToItemL( aPosition.iCurrentItemIndex,
                 CListBoxView::ESingleSelection );
         }
     else
         {
-        iListBox->View()->SetItemOffsetInPixels( aPosition.operator[](1) );
-        iListBox->View()->SetTopItemIndex( aPosition.operator[](2) );
+        iListBox->View()->SetItemOffsetInPixels( aPosition.iItemOffsetInPixels );
+        iListBox->View()->SetTopItemIndex( aPosition.iTopItemIndex );
         }
     }
 //End of File
@@ -834,42 +834,40 @@
 //
-//Get the exact position of listbox.
+//Store the exact position of listbox.
 // -----------------------------------------------------------------------------
 //
@@ -834,42 +834,40 @@
 //
-//Get the exact position of listbox.
+//Restore the exact position of listbox.
 // -----------------------------------------------------------------------------
 //